@@ -9,9 +9,6 @@ import numba
 import logging
 from numpy.lib import recfunctions
 
-logging.basicConfig(
-    level=logging.INFO,
-    format='%(asctime)s - %(threadName)s - %(name)s - %(levelname)s - %(message)s')
 log = logging.getLogger('Pema matching')
 
 export, __all__ = strax.exporter()
