@@ -43,7 +43,7 @@ def _create_dummy_records(data_length, n_data_types, truth_length, n_truth_types
 @example(length=3, dtypenum=0)
 def test_combine_and_flip(length, dtypenum):
     """Check that combine and flip works correctly"""
-    known_dtypes = (np.bool_, np.bool, np.int)
+    known_dtypes = (np.bool_, np.int8, np.int64)
     dtype = known_dtypes[dtypenum]
     arr1 = np.random.randint(0, 2, length).astype(dtype)
     arr2 = np.random.randint(0, 2, length).astype(dtype)
@@ -145,3 +145,47 @@ def get_deepwindows(windows, peaks_a, peaks_b, matching_fuzz):
         _deep_windows.append(this_window)
     deep_windows = np.array(_deep_windows, dtype=(np.int64, np.int64))
     return deep_windows
+
+
+def test_peak_merges():
+    """Test some examples"""
+    dtype = [(('outcome of matching', 'outcome'), pema.matching.OUTCOME_DTYPE),
+             (('Number', 'id'), np.int64),
+             (('matched to', 'matched_to'), np.int64),
+             (('type of p', 'type'), np.int16),
+             (('area of p', 'area'), np.float64)]
+    unknown_types = np.array([0])
+    parent = np.zeros(1, dtype=dtype)
+    fragment = np.zeros(2, dtype=dtype)
+
+    parent['type'] = 1
+    fragment['type'] = 1, 2
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert parent['outcome'] == 'split_and_misid'
+    assert fragment[0]['outcome'] == 'merged'
+    assert fragment[1]['outcome'] == 'merged_to_s1'
+
+    parent['type'] = 1
+    fragment['type'] = 1, 0
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert parent['outcome'] == 'chopped'
+
+    parent['type'] = 1
+    fragment['type'] = 1, 2
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert parent['outcome'] == 'split_and_misid'
+
+    parent['type'] = 1
+    fragment['type'] = 1, 1
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert parent['outcome'] == 'split'
+
+    parent['type'] = 0
+    fragment['type'] = 1, 1
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert fragment[0]['outcome'] == 'merged_to_unknown'
+
+    parent['type'] = 1
+    fragment['type'] = 0, 0
+    pema.matching.handle_peak_merge(parent[0], fragment, unknown_types)
+    assert parent['outcome'] == 'split_and_unclassified'
