@@ -130,8 +130,7 @@ class TestStack(unittest.TestCase):
         self.script.purge_below('match_acceptance_extended')
         for t in strax.to_str_tuple(self.script.target):
             for r in strax.to_str_tuple(self.script.run_id):
-                if (self.script.st._plugin_class_registry[t].save_when
-                        > strax.SaveWhen.NEVER):
+                if (self.script.st.get_save_when(t) > strax.SaveWhen.NEVER):
                     self.script.st.make(r, t)
                     assert self.script.st.is_stored(r, t)
 
@@ -213,13 +212,15 @@ class TestStack(unittest.TestCase):
 
     def test_later_inst_plot(self):
         st = self.script.st
-        peaks = st.get_array(run_id, 'peaks')
+        peaks = st.get_array(run_id, ('peaks', 'peak_basics'))
         st.plot_peaks(run_id, time_within=peaks[0])
         plt.clf()
         st.plot_peaks(run_id, time_within=peaks[0], xaxis='since_start')
+        pema.plot_peak(peaks[0], t0=None)
         plt.clf()
+
         st.plot_peaks(run_id, time_within=peaks[0], xaxis=False)
-        pema.save_canvas('test_fig', os.path.join(self.tempdir, 'figs'))
+        pema.save_canvas('test_fig', os.path.join(self.tempdir, 'figs'), tight_layout=True)
 
     @classmethod
     def tearDownClass(cls):
